@@ -19,7 +19,7 @@ class OpenfabricExecutionRay:
     def session_id(self):
         if self.__id is None:
             self.__id = uuid.uuid4().hex
-        return
+        return self.__id
 
     def progress(self, name, total=100) -> tqdm_asyncio:
         if self.__bars.get(name) is None:
