@@ -7,11 +7,11 @@ from flask_cors import CORS
 from openfabric_pysdk.config import manifest_config
 from openfabric_pysdk.manager import OpenfabricManager
 
-app = Flask(__name__, template_folder=f"{pathlib.Path(__file__).parent}/templates")
-CORS(app)
+OpenfabricApp = Flask(__name__, template_folder=f"{pathlib.Path(__file__).parent}/templates")
+CORS(OpenfabricApp)
 
 
-@app.route("/")
+@OpenfabricApp.route("/")
 def index():
     return render_template("index.html", manifest=manifest_config.all())
 
@@ -24,7 +24,7 @@ class OpenfabricStarter:
         logger = logging.getLogger()
         logger.setLevel(logging.INFO)
 
-        service = OpenfabricManager(app)
+        service = OpenfabricManager(OpenfabricApp)
 
         # Setup socket services
         service.install_execution_socket('/app')
