@@ -20,7 +20,7 @@ class OpenfabricExecutionRestApi(MethodResource, Resource):
         ray = OpenfabricExecutionRay(uuid.uuid4().hex)
 
         with MeasureBlockTime("OpenfabricExecutionRestApi::execution_callback_function"):
-            input_value: InputClass = args
+            input_value = list(args) if InputSchema().many is True else args[0]
             result = execution_callback_function(input_value, ray)
 
         return result
